@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2007-2011 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2007-2013 Juha Kautto  (juha at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -127,6 +127,12 @@ static void close_window(day_win *dw)
     appt_win *apptw;
     GList *apptw_list;
 
+    gtk_window_get_size(GTK_WINDOW(dw->Window)
+            , &g_par.dw_size_x, &g_par.dw_size_y);
+    gtk_window_get_position(GTK_WINDOW(dw->Window)
+            , &g_par.dw_pos_x, &g_par.dw_pos_y);
+    write_parameters();
+
     /* need to clean the appointment list and inform all appointments that
      * we are not interested anymore (= should not get updated) */
     apptw_list = dw->apptw_list;
@@ -142,7 +148,6 @@ static void close_window(day_win *dw)
     g_list_free(dw->apptw_list);
 
     gtk_widget_destroy(dw->Window);
-    gtk_object_destroy(GTK_OBJECT(dw->Tooltips));
     g_free(dw);
     dw = NULL;
 }
@@ -223,26 +228,46 @@ static void on_Go_today_activate_cb(GtkMenuItem *mi, gpointer user_data)
     go_to_today((day_win *)user_data);
 }
 
-static void on_Go_previous_activate_cb(GtkMenuItem *mi, gpointer user_data)
+static void on_Go_previous_week_activate_cb(GtkMenuItem *mi, gpointer user_data)
+{
+    changeSelectedDate((day_win *)user_data, -7);
+}
+
+static void on_Go_previous_day_activate_cb(GtkMenuItem *mi, gpointer user_data)
 {
     changeSelectedDate((day_win *)user_data, -1);
 }
 
-static void on_Previous_clicked(GtkButton *b, gpointer user_data)
+static void on_Previous_day_clicked(GtkButton *b, gpointer user_data)
 {
     changeSelectedDate((day_win *)user_data, -1);
 }
 
-static void on_Go_next_activate_cb(GtkMenuItem *mi, gpointer user_data)
+static void on_Previous_week_clicked(GtkButton *b, gpointer user_data)
+{
+    changeSelectedDate((day_win *)user_data, -7);
+}
+
+static void on_Go_next_day_activate_cb(GtkMenuItem *mi, gpointer user_data)
 {
     changeSelectedDate((day_win *)user_data, 1);
 }
 
-static void on_Next_clicked(GtkButton *b, gpointer user_data)
+static void on_Go_next_week_activate_cb(GtkMenuItem *mi, gpointer user_data)
+{
+    changeSelectedDate((day_win *)user_data, 7);
+}
+
+static void on_Next_day_clicked(GtkButton *b, gpointer user_data)
 {
     changeSelectedDate((day_win *)user_data, 1);
 }
 
+static void on_Next_week_clicked(GtkButton *b, gpointer user_data)
+{
+    changeSelectedDate((day_win *)user_data, 7);
+}
+
 static void build_menu(day_win *dw)
 {
     GtkWidget *menu_separator;
@@ -276,21 +301,51 @@ static void build_menu(day_win *dw)
 
     /********** Go menu   **********/
     dw->Go_menu = orage_menu_new(_("_Go"), dw->Menubar);
+
     dw->Go_menu_today = orage_image_menu_item_new_from_stock("gtk-home"
             , dw->Go_menu, dw->accel_group);
     gtk_widget_add_accelerator(dw->Go_menu_today
             , "activate", dw->accel_group
             , GDK_Home, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-    dw->Go_menu_prev = orage_image_menu_item_new_from_stock("gtk-go-back"
+    gtk_widget_add_accelerator(dw->Go_menu_today
+            , "activate", dw->accel_group
+            , GDK_KP_Home, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+
+    dw->Go_menu_prev_week = orage_image_menu_item_new_from_stock("gtk-go-up"
             , dw->Go_menu, dw->accel_group);
-    gtk_widget_add_accelerator(dw->Go_menu_prev
+    gtk_widget_add_accelerator(dw->Go_menu_prev_week
+            , "activate", dw->accel_group
+            , GDK_Page_Up, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(dw->Go_menu_prev_week
+            , "activate", dw->accel_group
+            , GDK_KP_Page_Up, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+
+    dw->Go_menu_prev_day = orage_image_menu_item_new_from_stock("gtk-go-back"
+            , dw->Go_menu, dw->accel_group);
+    gtk_widget_add_accelerator(dw->Go_menu_prev_day
             , "activate", dw->accel_group
             , GDK_Left, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
-    dw->Go_menu_next = orage_image_menu_item_new_from_stock("gtk-go-forward"
+    gtk_widget_add_accelerator(dw->Go_menu_prev_day
+            , "activate", dw->accel_group
+            , GDK_KP_Left, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+
+    dw->Go_menu_next_day = orage_image_menu_item_new_from_stock("gtk-go-forward"
             , dw->Go_menu, dw->accel_group);
-    gtk_widget_add_accelerator(dw->Go_menu_next
+    gtk_widget_add_accelerator(dw->Go_menu_next_day
             , "activate", dw->accel_group
             , GDK_Right, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(dw->Go_menu_next_day
+            , "activate", dw->accel_group
+            , GDK_KP_Right, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+
+    dw->Go_menu_next_week = orage_image_menu_item_new_from_stock("gtk-go-down"
+            , dw->Go_menu, dw->accel_group);
+    gtk_widget_add_accelerator(dw->Go_menu_next_week
+            , "activate", dw->accel_group
+            , GDK_Page_Down, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(dw->Go_menu_next_week
+            , "activate", dw->accel_group
+            , GDK_KP_Page_Down, GDK_MOD1_MASK, GTK_ACCEL_VISIBLE);
 
     g_signal_connect((gpointer)dw->File_menu_new, "activate"
             , G_CALLBACK(on_File_newApp_activate_cb), dw);
@@ -300,10 +355,14 @@ static void build_menu(day_win *dw)
             , G_CALLBACK(on_View_refresh_activate_cb), dw);
     g_signal_connect((gpointer)dw->Go_menu_today, "activate"
             , G_CALLBACK(on_Go_today_activate_cb), dw);
-    g_signal_connect((gpointer)dw->Go_menu_prev, "activate"
-            , G_CALLBACK(on_Go_previous_activate_cb), dw);
-    g_signal_connect((gpointer)dw->Go_menu_next, "activate"
-            , G_CALLBACK(on_Go_next_activate_cb), dw);
+    g_signal_connect((gpointer)dw->Go_menu_prev_week, "activate"
+            , G_CALLBACK(on_Go_previous_week_activate_cb), dw);
+    g_signal_connect((gpointer)dw->Go_menu_prev_day, "activate"
+            , G_CALLBACK(on_Go_previous_day_activate_cb), dw);
+    g_signal_connect((gpointer)dw->Go_menu_next_day, "activate"
+            , G_CALLBACK(on_Go_next_day_activate_cb), dw);
+    g_signal_connect((gpointer)dw->Go_menu_next_week, "activate"
+            , G_CALLBACK(on_Go_next_week_activate_cb), dw);
 }
 
 static void build_toolbar(day_win *dw)
@@ -313,38 +372,45 @@ static void build_toolbar(day_win *dw)
 
     dw->Toolbar = gtk_toolbar_new();
     gtk_box_pack_start(GTK_BOX(dw->Vbox), dw->Toolbar, FALSE, FALSE, 0);
-    gtk_toolbar_set_tooltips(GTK_TOOLBAR(dw->Toolbar), TRUE);
 
     dw->Create_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-new", dw->Tooltips, _("New"), i++);
+            , "gtk-new", _("New"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(dw->Toolbar, i++);
 
-    dw->Previous_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-go-back", dw->Tooltips, _("Back"), i++);
+    dw->Previous_week_toolbutton = orage_toolbar_append_button(dw->Toolbar
+            , "gtk-go-up", _("Back one week"), i++);
+    dw->Previous_day_toolbutton = orage_toolbar_append_button(dw->Toolbar
+            , "gtk-go-back", _("Back one day"), i++);
     dw->Today_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-home", dw->Tooltips, _("Today"), i++);
-    dw->Next_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-go-forward", dw->Tooltips, _("Forward"), i++);
+            , "gtk-home", _("Today"), i++);
+    dw->Next_day_toolbutton = orage_toolbar_append_button(dw->Toolbar
+            , "gtk-go-forward", _("Forward one day"), i++);
+    dw->Next_week_toolbutton = orage_toolbar_append_button(dw->Toolbar
+            , "gtk-go-down", _("Forward one week"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(dw->Toolbar, i++);
 
     dw->Refresh_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-refresh", dw->Tooltips, _("Refresh"), i++);
+            , "gtk-refresh", _("Refresh"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(dw->Toolbar, i++);
 
     dw->Close_toolbutton = orage_toolbar_append_button(dw->Toolbar
-            , "gtk-close", dw->Tooltips, _("Close"), i++);
+            , "gtk-close", _("Close"), i++);
 
     g_signal_connect((gpointer)dw->Create_toolbutton, "clicked"
             , G_CALLBACK(on_Create_toolbutton_clicked_cb), dw);
-    g_signal_connect((gpointer)dw->Previous_toolbutton, "clicked"
-            , G_CALLBACK(on_Previous_clicked), dw);
+    g_signal_connect((gpointer)dw->Previous_week_toolbutton, "clicked"
+            , G_CALLBACK(on_Previous_week_clicked), dw);
+    g_signal_connect((gpointer)dw->Previous_day_toolbutton, "clicked"
+            , G_CALLBACK(on_Previous_day_clicked), dw);
     g_signal_connect((gpointer)dw->Today_toolbutton, "clicked"
             , G_CALLBACK(on_Today_clicked), dw);
-    g_signal_connect((gpointer)dw->Next_toolbutton, "clicked"
-            , G_CALLBACK(on_Next_clicked), dw);
+    g_signal_connect((gpointer)dw->Next_day_toolbutton, "clicked"
+            , G_CALLBACK(on_Next_day_clicked), dw);
+    g_signal_connect((gpointer)dw->Next_week_toolbutton, "clicked"
+            , G_CALLBACK(on_Next_week_clicked), dw);
     g_signal_connect((gpointer)dw->Refresh_toolbutton, "clicked"
             , G_CALLBACK(on_Refresh_clicked), dw);
     g_signal_connect((gpointer)dw->Close_toolbutton, "clicked"
@@ -385,8 +451,14 @@ static void on_spin_changed(GtkSpinButton *b, gpointer *user_data)
 static void on_Date_button_clicked_cb(GtkWidget *button, gpointer *user_data)
 {
     day_win *dw = (day_win *)user_data;
+    GtkWidget *selDate_dialog;
 
-    if (orage_date_button_clicked(button, dw->Window))
+     selDate_dialog = gtk_dialog_new_with_buttons(
+             _("Pick the date"), GTK_WINDOW(dw->Window),
+             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+             _("Today"), 1, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+
+    if (orage_date_button_clicked(button, selDate_dialog))
         refresh_day_win(dw);
 }
 
@@ -410,6 +482,12 @@ static void on_button_press_event_cb(GtkWidget *widget
     }
 }
 
+static void on_arrow_up_press_event_cb(GtkWidget *widget
+        , GdkEventButton *event, gpointer *user_data)
+{
+    changeSelectedDate((day_win *)user_data, -7);
+}
+
 static void on_arrow_left_press_event_cb(GtkWidget *widget
         , GdkEventButton *event, gpointer *user_data)
 {
@@ -422,15 +500,23 @@ static void on_arrow_right_press_event_cb(GtkWidget *widget
     changeSelectedDate((day_win *)user_data, 1);
 }
 
+static void on_arrow_down_press_event_cb(GtkWidget *widget
+        , GdkEventButton *event, gpointer *user_data)
+{
+    changeSelectedDate((day_win *)user_data, 7);
+}
+
 static void add_row(day_win *dw, xfical_appt *appt)
 {
-    gint row, start_row, end_row;
+    gint row, start_row, end_row, days;
     gint col, start_col, end_col, first_col, last_col;
     gint height, start_height, end_height;
-    gchar *tip, *start_date, *end_date, *tmp_title, *tmp_note;
+    gchar *tip, *start_date, *end_date, *tmp_title, *tip_title;
+    gchar *tmp_note, *tip_note;
     GtkWidget *ev, *lab, *hb;
     struct tm tm_start, tm_end, tm_first;
     GdkColor *color;
+    gchar *format_bold = "<b> %s </b>";
 
     /* First clarify timings */
     tm_start = orage_icaltime_to_tm_time(appt->starttimecur, FALSE);
@@ -438,7 +524,11 @@ static void add_row(day_win *dw, xfical_appt *appt)
     tm_first = orage_icaltime_to_tm_time(dw->a_day, FALSE);
     start_col = orage_days_between(&tm_first, &tm_start)+1;
     end_col   = orage_days_between(&tm_first, &tm_end)+1;
+    days      = orage_days_between(&tm_start, &tm_end);
 
+    if (start_col > dw->days) { /* can happen if timezones pass date change */
+        return; /* this does not fit, so we just skip it */
+    }
     if (start_col < 1) {
         col = 1;
         row = 0;
@@ -447,16 +537,27 @@ static void add_row(day_win *dw, xfical_appt *appt)
         col = start_col;
         row = tm_start.tm_hour;
     }
+    if (end_col < 1) { /* can happen if timezones pass date change */
+        return; /* this does not fit, so we just skip it */
+    }
+    if (end_col > dw->days) { /* can happen if timezones pass date change */
+        end_col = days;
+    }
 
     /* then add the appointment */
     tmp_title = orage_process_text_commands(
             appt->title ? appt->title : _("Unknown"));
-    tmp_note = orage_process_text_commands(appt->note);
+    tip_title = g_markup_printf_escaped(format_bold, tmp_title);
+    tmp_note = orage_process_text_commands(
+            appt->note ? appt->note : "");
+    tmp_note = orage_limit_text(tmp_note, 50, 10);
+    tip_note = g_markup_escape_text(tmp_note, strlen(tmp_note));
+    g_free(tmp_note);
     ev = gtk_event_box_new();
     lab = gtk_label_new(tmp_title);
     gtk_container_add(GTK_CONTAINER(ev), lab);
 
-    if (appt->starttimecur[8] != 'T') { /* whole day event */
+    if (appt->allDay) { /* whole day event */
         gtk_widget_modify_bg(ev, GTK_STATE_NORMAL, &dw->bg2);
         if (dw->header[col] == NULL) { /* first data */
             hb = gtk_hbox_new(TRUE, 3);
@@ -468,8 +569,22 @@ static void add_row(day_win *dw, xfical_appt *appt)
              * have more than 1 appointment here
              */
         }
-        tip = g_strdup_printf("%s\n%s - %s\n%s"
-                , tmp_title, appt->starttimecur, appt->endtimecur, tmp_note);
+    /* we took the date in unnormalized format, so we need to do that now */
+        tm_start.tm_year -= 1900;
+        tm_start.tm_mon -= 1;
+        start_date = g_strdup(orage_tm_date_to_i18_date(&tm_start));
+        if (days == 0)
+            tip = g_strdup_printf("%s\n%s\n%s"
+                    , tip_title, start_date, tip_note);
+        else {
+            tm_end.tm_year -= 1900;
+            tm_end.tm_mon -= 1;
+            end_date = g_strdup(orage_tm_date_to_i18_date(&tm_end));
+            tip = g_strdup_printf("%s\n%s - %s\n%s"
+                    , tip_title, start_date, end_date, tip_note);
+            g_free(end_date);
+        }
+        g_free(start_date);
     }
     else {
         if ((color = orage_category_list_contains(appt->categories)) != NULL)
@@ -486,10 +601,10 @@ static void add_row(day_win *dw, xfical_appt *appt)
              * have more than 1 appointment here
              */
         }
-        if (orage_days_between(&tm_start, &tm_end) == 0)
+        if (days == 0)
             tip = g_strdup_printf("%s\n%02d:%02d-%02d:%02d\n%s"
-                    , tmp_title, tm_start.tm_hour, tm_start.tm_min
-                    , tm_end.tm_hour, tm_end.tm_min, tmp_note);
+                    , tip_title, tm_start.tm_hour, tm_start.tm_min
+                    , tm_end.tm_hour, tm_end.tm_min, tip_note);
         else {
     /* we took the date in unnormalized format, so we need to do that now */
             tm_start.tm_year -= 1900;
@@ -499,14 +614,14 @@ static void add_row(day_win *dw, xfical_appt *appt)
             start_date = g_strdup(orage_tm_date_to_i18_date(&tm_start));
             end_date = g_strdup(orage_tm_date_to_i18_date(&tm_end));
             tip = g_strdup_printf("%s\n%s %02d:%02d - %s %02d:%02d\n%s"
-                    , tmp_title
+                    , tip_title
                     , start_date, tm_start.tm_hour, tm_start.tm_min
-                    , end_date, tm_end.tm_hour, tm_end.tm_min, tmp_note);
+                    , end_date, tm_end.tm_hour, tm_end.tm_min, tip_note);
             g_free(start_date);
             g_free(end_date);
         }
     }
-    gtk_tooltips_set_tip(dw->Tooltips, ev, tip, NULL);
+    gtk_widget_set_tooltip_markup(ev, tip);
     /*
     gtk_box_pack_start(GTK_BOX(hb2), ev, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(hb), hb2, TRUE, TRUE, 0);
@@ -515,14 +630,15 @@ static void add_row(day_win *dw, xfical_appt *appt)
     g_object_set_data_full(G_OBJECT(ev), "UID", g_strdup(appt->uid), g_free);
     g_signal_connect((gpointer)ev, "button-press-event"
             , G_CALLBACK(on_button_press_event_cb), dw);
-    g_free(tip);
     g_free(tmp_title);
-    g_free(tmp_note);
+    g_free(tip);
+    g_free(tip_title);
+    g_free(tip_note);
 
     /* and finally draw the line to show how long the appointment is,
      * but only if it is Busy type event (=availability != 0) 
      * and it is not whole day event */
-    if (appt->availability && appt->starttimecur[8] == 'T') {
+    if (appt->availability && !appt->allDay) {
         height = dw->StartDate_button_req.height;
         /*
          * same_date = !strncmp(start_ical_time, end_ical_time, 8);
@@ -675,13 +791,15 @@ static void fill_days(day_win *dw, gint days)
 static void build_day_view_header(day_win *dw, char *start_date)
 {
     GtkWidget *hbox, *label;
+    struct tm tm_date;
+    char *first_date;
+    int diff_to_weeks_first_day;
 
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(dw->Vbox), hbox, FALSE, FALSE, 10);
 
     label = gtk_label_new(_("Start"));
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 10);
-
     /* start date button */
     dw->StartDate_button = gtk_button_new();
     gtk_box_pack_start(GTK_BOX(hbox), dw->StartDate_button, FALSE, FALSE, 0);
@@ -695,8 +813,26 @@ static void build_day_view_header(day_win *dw, char *start_date)
     gtk_box_pack_start(GTK_BOX(hbox), dw->day_spin, FALSE, FALSE, 0);
 
     /* initial values */
+    if (g_par.dw_week_mode) { /* we want to start form week start day */
+        tm_date = orage_i18_date_to_tm_date(start_date);
+        /* tm_date.wday: 0 = Sunday, 1 = Monday, 2 = Tuesday, ... 6 = Saturday
+           g_par.ical_weekstartday: 0 = Monday, 1 = Tuesday, ... 6 = Sunday */
+        diff_to_weeks_first_day = tm_date.tm_wday - (g_par.ical_weekstartday+1);
+        if (diff_to_weeks_first_day < 0)
+            diff_to_weeks_first_day += 7;
+        if (diff_to_weeks_first_day == 0) { /* we are on week start day */
+            first_date = start_date;
+        }
+        else {
+            orage_move_day(&tm_date, -1*diff_to_weeks_first_day);
+            first_date = orage_tm_date_to_i18_date(&tm_date);
+        }
+    }
+    else {
+        first_date = start_date;
+    }
     gtk_button_set_label(GTK_BUTTON(dw->StartDate_button)
-            , (const gchar *)start_date);
+            , (const gchar *)first_date);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dw->day_spin), 7);
 
     /* sizes */
@@ -774,15 +910,29 @@ static void fill_hour_arrow(day_win *dw, gint col)
     GtkWidget *arrow, *ev;
 
     ev = gtk_event_box_new();
-    if (col == 0) {
-        arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
-        g_signal_connect((gpointer)ev, "button-press-event"
-                , G_CALLBACK(on_arrow_left_press_event_cb), dw);
+    if (g_par.dw_week_mode) {
+        if (col == 0) {
+            arrow = gtk_arrow_new(GTK_ARROW_UP, GTK_SHADOW_NONE);
+            g_signal_connect((gpointer)ev, "button-press-event"
+                    , G_CALLBACK(on_arrow_up_press_event_cb), dw);
+        }
+        else {
+            arrow = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_NONE);
+            g_signal_connect((gpointer)ev, "button-press-event"
+                    , G_CALLBACK(on_arrow_down_press_event_cb), dw);
+        }
     }
     else {
-        arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
-        g_signal_connect((gpointer)ev, "button-press-event"
-                , G_CALLBACK(on_arrow_right_press_event_cb), dw);
+        if (col == 0) {
+            arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_NONE);
+            g_signal_connect((gpointer)ev, "button-press-event"
+                    , G_CALLBACK(on_arrow_left_press_event_cb), dw);
+        }
+        else {
+            arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
+            g_signal_connect((gpointer)ev, "button-press-event"
+                    , G_CALLBACK(on_arrow_right_press_event_cb), dw);
+        }
     }
     gtk_container_add(GTK_CONTAINER(ev), arrow);
     gtk_widget_set_size_request(ev, dw->hour_req.width
@@ -912,11 +1062,14 @@ day_win *create_day_win(char *start_date)
     /* initialisation + main window + base vbox */
     dw = g_new0(day_win, 1);
     dw->scroll_pos = -1; /* not set */
-    dw->Tooltips = gtk_tooltips_new();
     dw->accel_group = gtk_accel_group_new();
 
     dw->Window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_default_size(GTK_WINDOW(dw->Window), 690, 390);
+    if (g_par.dw_size_x || g_par.dw_size_y)
+        gtk_window_set_default_size(GTK_WINDOW(dw->Window)
+                , g_par.dw_size_x, g_par.dw_size_y);
+    if (g_par.dw_pos_x || g_par.dw_pos_y)
+        gtk_window_move(GTK_WINDOW(dw->Window), g_par.dw_pos_x, g_par.dw_pos_y);
     gtk_window_set_title(GTK_WINDOW(dw->Window), _("Orage - day view"));
     gtk_window_add_accel_group(GTK_WINDOW(dw->Window), dw->accel_group);
 
