@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2013 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2004-2005 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,6 +49,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
+#include <glib.h>
 #include <glib/gprintf.h>
 
 #include "orage-i18n.h"
@@ -373,9 +374,10 @@ static void add_el_row(el_win *el, xfical_appt *appt, char *par)
     guint           len = 50;
 
     stime = format_time(el, appt, par);
-    if (appt->alarmtime != 0)
-        if (appt->sound != NULL)
-            flags[0] = 'S';
+    if (appt->display_alarm_orage || appt->display_alarm_notify 
+    ||  appt->sound_alarm || appt->procedure_alarm)
+        if (appt->alarm_persistent)
+            flags[0] = 'P';
         else
             flags[0] = 'A';
     else
@@ -391,8 +393,10 @@ static void add_el_row(el_win *el, xfical_appt *appt, char *par)
         flags[1] = 'M';
     else if (appt->freq == XFICAL_FREQ_YEARLY)
         flags[1] = 'Y';
+    else if (appt->freq == XFICAL_FREQ_HOURLY)
+        flags[1] = 'H';
     else
-        flags[1] = 'n';
+        flags[1] = '?';
 
     if (appt->availability != 0)
         flags[2] = 'B';
@@ -497,7 +501,7 @@ static void app_rows(el_win *el, char *a_day, char *par, xfical_type ical_type
     GList *appt_list=NULL, *tmp;
     xfical_appt *appt;
 
-    if (ical_type == XFICAL_TYPE_EVENT) {
+    if (ical_type == XFICAL_TYPE_EVENT && !el->only_first) {
         xfical_get_each_app_within_time(a_day, el->days+1
                 , ical_type, file_type, &appt_list);
         for (tmp = g_list_first(appt_list);
@@ -517,7 +521,19 @@ static void app_rows(el_win *el, char *a_day, char *par, xfical_type ical_type
              appt;
              appt = xfical_appt_get_next_on_day(a_day, FALSE, el->days
                     , ical_type, file_type)) {
-            add_el_row(el, appt, par);
+            /*
+            g_print("Title: %s a_day %s\n\tstart %s end %s\n \tcur start %s end %s\n "
+                  , appt->title, a_day
+                  , appt->starttime, appt->endtime
+                  , appt->starttimecur, appt->endtimecur
+                      );
+                      */
+            /* fix bug 8508: Do not show event if it is normal (= has time)
+               and it has ended at midnight (=early morning) */
+            if (!(appt->endtimecur[8] == 'T' 
+                && strncmp(appt->endtimecur+9, "000000", 6) == 0
+                && strncmp(appt->endtimecur, a_day, 8) == 0))
+                add_el_row(el, appt, par);
             xfical_appt_free(appt);
         }
     }
@@ -590,20 +606,40 @@ static void event_data(el_win *el)
     char      *stime;  /* in icaltime format */
     char      a_day[9]; /* yyyymmdd */
     struct tm *t, t_title;
+    GDate *d1, *d2;
 
     if (el->days == 0)
         refresh_time_field(el);
     el->days = gtk_spin_button_get_value(GTK_SPIN_BUTTON(el->event_spin));
+    /*
+    el->only_first = gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(el->event_only_first_checkbutton));
+            */
+    el->show_old = gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(el->event_show_old_checkbutton));
     title = (char *)gtk_window_get_title(GTK_WINDOW(el->Window));
     t_title = orage_i18_date_to_tm_date(title); 
-    stime = orage_tm_time_to_icaltime(&t_title);
-    strncpy(a_day, stime, 8);
+    if (el->show_old && el->only_first) {
+        /* just take any old enough date, so that all events fit in */
+        strncpy(a_day, "19000101", 8); 
+        /* we need to adjust also number of days shown */
+        d1 = g_date_new_dmy(1, 1, 1900);
+        d2 = g_date_new_dmy(t_title.tm_mday, t_title.tm_mon+1
+                , t_title.tm_year+1900);
+        el->days += g_date_days_between(d1, d2);
+        g_date_free(d1);
+        g_date_free(d2);
+    }
+    else { /* we show starting from selected day */
+        stime = orage_tm_time_to_icaltime(&t_title);
+        strncpy(a_day, stime, 8);
+    }
     a_day[8] = '\0';
     t = orage_localtime();
     g_sprintf(el->time_now, "%02d:%02d", t->tm_hour, t->tm_min);
-    if (   t_title.tm_year == t->tm_year
-        && t_title.tm_mon  == t->tm_mon
-        && t_title.tm_mday == t->tm_mday)
+    if (t_title.tm_year == t->tm_year
+    &&  t_title.tm_mon  == t->tm_mon
+    &&  t_title.tm_mday == t->tm_mday)
         el->today = TRUE;
     else
         el->today = FALSE; 
@@ -789,7 +825,6 @@ static void close_window(el_win *el)
     g_list_free(el->apptw_list);
 
     gtk_widget_destroy(el->Window); /* destroy the eventlist window */
-    gtk_object_destroy(GTK_OBJECT(el->Tooltips));
     g_free(el);
     el = NULL;
 }
@@ -903,6 +938,21 @@ static void on_spin_changed(GtkSpinButton *b, gpointer user_data)
     refresh_el_win((el_win *)user_data);
 }
 
+static void on_only_first_clicked(GtkCheckButton *b, gpointer user_data)
+{
+    el_win *el = (el_win *)user_data;
+
+    el->only_first = gtk_toggle_button_get_active(
+            GTK_TOGGLE_BUTTON(el->event_only_first_checkbutton));
+    gtk_widget_set_sensitive(el->event_show_old_checkbutton, el->only_first);
+    refresh_el_win((el_win *)user_data);
+}
+
+static void on_show_old_clicked(GtkCheckButton *b, gpointer user_data)
+{
+    refresh_el_win((el_win *)user_data);
+}
+
 static void delete_appointment(el_win *el)
 {
     gint result;
@@ -912,11 +962,14 @@ static void delete_appointment(el_win *el)
     GtkTreeIter       iter;
     GList *list;
     gint  list_len, i;
-    gchar *uid = NULL;
+    gchar *uid = NULL, *flags = NULL;
 
     result = orage_warning_dialog(GTK_WINDOW(el->Window)
             , _("You will permanently remove all\nselected appointments.")
-            , _("Do you want to continue?"));
+            , _("Do you want to continue?")
+            , _("No, cancel the removal")
+            , _("Yes, remove them"));
+
     if (result == GTK_RESPONSE_YES) {
         if (!xfical_file_open(TRUE))
             return;
@@ -927,6 +980,18 @@ static void delete_appointment(el_win *el)
             path = (GtkTreePath *)g_list_nth_data(list, i);
             if (gtk_tree_model_get_iter(model, &iter, path)) {
                 gtk_tree_model_get(model, &iter, COL_UID, &uid, -1);
+#ifdef HAVE_ARCHIVE
+                gtk_tree_model_get(model, &iter, COL_FLAGS, &flags, -1);
+                if (flags && flags[3] == 'A') {
+                    xfical_unarchive_uid(uid);
+                    /* note that file id changes after archive */ 
+                    uid[0]='O';
+                    /* xfical_unarchive_uid closes the file */
+                    if (!xfical_file_open(TRUE)) 
+                        return;
+                }
+                g_free(flags);
+#endif
                 result = xfical_appt_del(uid);
                 if (result)
                     orage_message(30, "Removed: %s", uid);
@@ -957,7 +1022,14 @@ static void on_journal_start_button_clicked(GtkWidget *button
         , gpointer *user_data)
 {
     el_win *el = (el_win *)user_data;
-    if (orage_date_button_clicked(button, el->Window))
+    GtkWidget *selDate_dialog;
+
+    selDate_dialog = gtk_dialog_new_with_buttons(
+            _("Pick the date"), GTK_WINDOW(el->Window),
+            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+            _("Today"), 1, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
+
+    if (orage_date_button_clicked(button, selDate_dialog))
         refresh_el_win(el);
 }
 
@@ -1092,37 +1164,36 @@ static void build_toolbar(el_win *el)
 
     el->Toolbar = gtk_toolbar_new();
     gtk_box_pack_start(GTK_BOX(el->Vbox), el->Toolbar, FALSE, FALSE, 0);
-    gtk_toolbar_set_tooltips(GTK_TOOLBAR(el->Toolbar), TRUE);
 
     el->Create_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-new", el->Tooltips, _("New"), i++);
+            , "gtk-new", _("New"), i++);
     el->Copy_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-copy", el->Tooltips, _("Duplicate"), i++);
+            , "gtk-copy", _("Duplicate"), i++);
     el->Delete_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-delete", el->Tooltips, _("Delete"), i++);
+            , "gtk-delete", _("Delete"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(el->Toolbar, i++);
     
     el->Previous_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-go-back", el->Tooltips, _("Back"), i++);
+            , "gtk-go-back", _("Back"), i++);
     el->Today_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-home", el->Tooltips, _("Today"), i++);
+            , "gtk-home", _("Today"), i++);
     el->Next_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-go-forward", el->Tooltips, _("Forward"), i++);
+            , "gtk-go-forward", _("Forward"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(el->Toolbar, i++);
 
     el->Refresh_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-refresh", el->Tooltips, _("Refresh"), i++);
+            , "gtk-refresh", _("Refresh"), i++);
     el->Search_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-find", el->Tooltips, _("Find"), i++);
+            , "gtk-find", _("Find"), i++);
 
     toolbar_separator = orage_toolbar_append_separator(el->Toolbar, i++);
 
     el->Close_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-close", el->Tooltips, _("Close"), i++);
+            , "gtk-close", _("Close"), i++);
     el->Dayview_toolbutton = orage_toolbar_append_button(el->Toolbar
-            , "gtk-zoom-in", el->Tooltips, _("Dayview"), i++);
+            , "gtk-zoom-in", _("Dayview"), i++);
 
     g_signal_connect((gpointer)el->Create_toolbutton, "clicked"
             , G_CALLBACK(on_Create_toolbutton_clicked_cb), el);
@@ -1149,23 +1220,53 @@ static void build_toolbar(el_win *el)
 static void build_event_tab(el_win *el)
 {
     GtkWidget *label;
+    GtkWidget *hbox;
 
+    hbox =  gtk_hbox_new(FALSE, 0);
     el->event_tab_label = gtk_label_new(_("Event"));
     /* we do not really need table, but it is efficient and easy way to
        do this. Using hboxes takes actually more memory */
     el->event_notebook_page = orage_table_new(1, BORDER_SIZE);
 
-    label = gtk_label_new(_("Extra days to show "));
-    el->event_spin = gtk_spin_button_new_with_range(0, 999, 1);
+    label = gtk_label_new(_("Extra days to show:"));
+
+    el->event_spin = gtk_spin_button_new_with_range(0, 99999, 1);
+    gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(el->event_spin), TRUE);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(el->event_spin)
             , (gdouble)el->days);
+    gtk_box_pack_start(GTK_BOX(hbox), el->event_spin, FALSE, FALSE, 2);
+
+    el->event_only_first_checkbutton =
+            gtk_check_button_new_with_label(_("only first repeating"));
+    gtk_toggle_button_set_active(
+            GTK_TOGGLE_BUTTON(el->event_only_first_checkbutton)
+                    , el->only_first);
+    gtk_widget_set_tooltip_text(el->event_only_first_checkbutton
+            , _("Check this if you only want to see the first repeating event. By default all are shown.\nNote that this also shows all urgencies.\nNote that repeating events may appear earlier in the list as the first occurrence only is listed."));
+    gtk_box_pack_start(GTK_BOX(hbox), el->event_only_first_checkbutton
+            , FALSE, FALSE, 15);
+
+    el->event_show_old_checkbutton =
+            gtk_check_button_new_with_label(_("also old"));
+    gtk_widget_set_tooltip_text(el->event_show_old_checkbutton
+            , _("Check this if you want to see old events also. This can only be selected after 'only first repeating' is enabled to avoid very long lists.\nNote that extra days selection still defines if newer appointments are listed'."));
+    gtk_toggle_button_set_active(
+            GTK_TOGGLE_BUTTON(el->event_show_old_checkbutton), el->only_first);
+    gtk_widget_set_sensitive(el->event_show_old_checkbutton, el->only_first);
+    gtk_box_pack_start(GTK_BOX(hbox), el->event_show_old_checkbutton
+            , FALSE, FALSE, 15);
+
     orage_table_add_row(el->event_notebook_page
-            , label, el->event_spin, 0, (GTK_FILL), (0));
+            , label, hbox, 0, (GTK_FILL), (0));
 
     gtk_notebook_append_page(GTK_NOTEBOOK(el->Notebook)
             , el->event_notebook_page, el->event_tab_label);
     g_signal_connect((gpointer)el->event_spin, "value-changed"
             , G_CALLBACK(on_spin_changed), el);
+    g_signal_connect((gpointer)el->event_only_first_checkbutton, "clicked"
+            , G_CALLBACK(on_only_first_clicked), el);
+    g_signal_connect((gpointer)el->event_show_old_checkbutton, "clicked"
+            , G_CALLBACK(on_show_old_clicked), el);
 }
 
 static void build_todo_tab(el_win *el)
@@ -1308,7 +1409,7 @@ static void build_event_list(el_win *el)
     gtk_tree_view_append_column(GTK_TREE_VIEW(el->TreeView), col);
     gtk_tree_view_column_set_visible(col, FALSE);
 
-    gtk_tooltips_set_tip(el->Tooltips, el->TreeView, _("Double click line to edit it.\n\nFlags in order:\n\t 1. Alarm: n=no alarm\n\t\t A=visual Alarm S=also Sound alarm\n\t 2. Recurrence: n=no recurrence\n\t\t D=Daily W=Weekly M=Monthly Y=Yearly\n\t 3. Type: f=free B=Busy\n\t 4. Located in file:\n\t\tO=Orage A=Archive F=Foreign\n\t 5. Appointment type:\n\t\tE=Event T=Todo J=Journal"), NULL);
+    gtk_widget_set_tooltip_text(el->TreeView, _("Double click line to edit it.\n\nFlags in order:\n\t 1. Alarm: n=no alarm\n\t\t A=Alarm is set P=Persistent alarm is set\n\t 2. Recurrence: n=no recurrence\n\t\t H=Hourly D=Daily W=Weekly M=Monthly Y=Yearly\n\t 3. Type: f=free B=Busy\n\t 4. Located in file:\n\t\tO=Orage A=Archive F=Foreign\n\t 5. Appointment type:\n\t\tE=Event T=Todo J=Journal"));
 
     g_signal_connect(el->TreeView, "row-activated",
             G_CALLBACK(editEvent), el);
@@ -1323,9 +1424,10 @@ el_win *create_el_win(char *start_date)
     el = g_new(el_win, 1);
     el->today = FALSE;
     el->days = g_par.el_days;
+    el->only_first = g_par.el_only_first;
+    el->show_old = el->only_first;
     el->time_now[0] = 0;
     el->apptw_list = NULL;
-    el->Tooltips = gtk_tooltips_new();
     el->accel_group = gtk_accel_group_new();
 
     el->Window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
