@@ -76,17 +76,6 @@
 */
 
 
-
-extern icalset *ic_fical;
-extern icalcomponent *ic_ical;
-#ifdef HAVE_ARCHIVE
-extern icalset *ic_afical;
-extern icalcomponent *ic_aical;
-#endif
-
-extern gboolean ic_file_modified; /* has any ical file been changed */
-
-
 #ifdef HAVE_ARCHIVE
 gboolean xfical_archive_open(void)
 {
@@ -101,7 +90,7 @@ gboolean xfical_archive_open(void)
         return(FALSE);
 
     return(ic_internal_file_open(&ic_aical, &ic_afical, g_par.archive_file
-            , FALSE));
+            , FALSE, FALSE));
 }
 #endif
 
@@ -330,6 +319,7 @@ gboolean xfical_archive(void)
     xfical_period per;
     icalcomponent *c, *c2;
     icalproperty *p;
+    struct tm tm_threshold;
     struct tm *threshold;
     char *uid;
 
@@ -344,7 +334,8 @@ gboolean xfical_archive(void)
         orage_message(250, P_N "file open error");
         return(FALSE);
     }
-    threshold = orage_localtime();
+    memcpy(&tm_threshold, orage_localtime(), sizeof(tm_threshold));
+    threshold=&tm_threshold;
     threshold->tm_mday = 1;
     threshold->tm_year += 1900;
     threshold->tm_mon += 1; /* convert from 0...11 to 1...12 */
@@ -463,9 +454,9 @@ gboolean xfical_unarchive(void)
         xfical_file_close(FALSE);
         return(FALSE);
     }
-    for (c = icalcomponent_get_first_component(ic_aical, ICAL_VEVENT_COMPONENT);
+    for (c = icalcomponent_get_first_component(ic_aical, ICAL_ANY_COMPONENT);
          c != 0;
-         c = icalcomponent_get_next_component(ic_aical, ICAL_VEVENT_COMPONENT)) {
+         c = icalcomponent_get_next_component(ic_aical, ICAL_ANY_COMPONENT)) {
     /* Add to the base file */
         d = icalcomponent_new_clone(c);
         icalcomponent_add_component(ic_ical, d);
