@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2013 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2003-2006 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -56,6 +56,7 @@
 #include "interface.h"
 #ifdef HAVE_DBUS
 #include "orage-dbus.h"
+#include <dbus/dbus-glib-lowlevel.h>
 #endif
 
 /* session client handler */
@@ -64,6 +65,80 @@ static SessionClient	*session_client = NULL;
 */
 static GdkAtom atom_alive;
 
+#ifdef HAVE_DBUS
+static gboolean resume_after_sleep(gpointer user_data)
+{
+    orage_message(10, "Resuming after sleep");
+    alarm_read();
+    orage_day_change(&g_par);
+    return(FALSE); /* only once */
+}
+
+static void resuming_cb(DBusGProxy *proxy, gpointer user_data)
+{
+    orage_message(10, "Resuming");
+    /* we need this delay to prevent updating tray icon too quickly when
+       the normal code handles it also */
+    g_timeout_add_seconds(2, (GtkFunction) resume_after_sleep, NULL);
+}
+
+static void handle_resuming(void)
+{
+    DBusGConnection *connection;
+    GError *error = NULL;
+    DBusGProxy *proxy;
+
+    g_type_init();
+    connection = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
+    if (connection) {
+       proxy = dbus_g_proxy_new_for_name(connection, "org.freedesktop.UPower"
+               , "/org/freedesktop/UPower", "org.freedesktop.UPower");
+       if (proxy) {
+           dbus_g_proxy_add_signal(proxy, "Resuming", G_TYPE_INVALID);
+           dbus_g_proxy_connect_signal(proxy, "Resuming"
+                   , G_CALLBACK(resuming_cb), NULL, NULL);
+       } 
+       else {
+           g_warning("Failed to create proxy object\n");
+       }
+    } 
+    else {
+        g_warning("Failed to connect to D-BUS daemon: %s\n", error->message);
+    }
+}
+#endif
+
+
+/* This function monitors that we do not loose time.  It checks if longer time
+   than expected wakeup time has passed and fixes timings if that is the case.
+   This is needed since sometimes hibernate and suspend does not do a good job
+   in firing Orage timers and timing gets wrong. 
+NOTE: called from parameters.c set_wakeup_timer
+*/
+gboolean check_wakeup(gpointer user_data)
+{
+    static time_t tt_prev=0;
+    time_t tt_new=0;
+
+    tt_new = time(NULL);
+    if (tt_new - tt_prev > ORAGE_WAKEUP_TIMER_PERIOD * 2) {
+        /* we very rarely come here. */ 
+        /* user_data is normally NULL, but first call it has some value, 
+           which means that this is init call */
+        if (!user_data) { /* normal timer call */
+            orage_message(10, "wakeup timer refreshing");
+            alarm_read();
+            /* It is quite possible that day did not change, 
+               but we need to reset timers */
+            orage_day_change(&tt_prev); 
+        }
+        else {
+            orage_message(10, "wakeup timer init %d", tt_prev);
+        }
+    }
+    tt_prev = tt_new;
+    return(TRUE);
+}
 
 static void send_event(char *event)
 {
@@ -94,10 +169,27 @@ static void raise_orage(void)
     send_event("_XFCE_CALENDAR_RAISE");
 }
 
+static gboolean keep_tidy(void)
+{
+#ifdef HAVE_ARCHIVE
+    /* move old appointment to other file to keep the active
+       calendar file smaller and faster */
+    xfical_archive();
+#endif
+    
+    write_parameters();
+    return(TRUE);
+}
+
 static gboolean mWindow_delete_event_cb(GtkWidget *widget, GdkEvent *event
         , gpointer user_data)
 {
-    orage_toggle_visible();
+    if (g_par.close_means_quit) {
+        gtk_main_quit();
+    }
+    else {
+        orage_toggle_visible();
+    }
     return(TRUE);
 }
 
@@ -152,16 +244,6 @@ static gboolean client_message_received(GtkWidget *widget
     return(FALSE);
 }
 
-static gboolean keep_tidy(void)
-{
-#ifdef HAVE_ARCHIVE
-    /* move old appointment to other file to keep the active
-       calendar file smaller and faster */
-    xfical_archive();
-#endif
-    return(TRUE);
-}
-
 /*
  * SaveYourself callback
  *
@@ -234,7 +316,7 @@ static void print_help(void)
     g_print(_("--help (-h) \t\tprint this text\n"));
     g_print(_("--preferences (-p) \tshow preferences form\n"));
     g_print(_("--toggle (-t) \t\tmake orage visible/unvisible\n"));
-    g_print(_("--add-foreign (-a) file [RW] \tadd a foreign file\n"));
+    g_print(_("--add-foreign (-a) file [RW] [name] \tadd a foreign file\n"));
     g_print(_("--remove-foreign (-r) file \tremove a foreign file\n"));
     g_print(_("--export (-e) file [appointment...] \texport appointments from Orage to file\n"));
     g_print("\n");
@@ -297,24 +379,25 @@ static void export_file(gboolean running, char *file_name, gboolean initialized
 }
 
 static void add_foreign(gboolean running, char *file_name, gboolean initialized
-        , gboolean read_only)
+        , gboolean read_only, char *name)
 {
+    g_print("\nadd_foreign: file_name%s name:%s\n\n", file_name, name);
     if (running && !initialized) {
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
-        if (orage_dbus_foreign_add(file_name, read_only))
-            orage_message(40, "add done foreign file=%s", file_name);
+        if (orage_dbus_foreign_add(file_name, read_only, name))
+            orage_message(40, "Add done online foreign file=%s", file_name);
         else
-            g_warning("add failed foreign file=%s\n", file_name);
+            orage_message(140, "Add failed online foreign file=%s\n", file_name);
 #else
-        g_warning("Can not do add foreign file without dbus. failed file=%s\n", file_name);
+        orage_message(140, "Can not do add foreign file to running Orage without dbus. Add failed foreign file=%s\n", file_name);
 #endif
     }
     else if (!running && initialized) { /* do it self directly */
-        if (orage_foreign_file_add(file_name, read_only))
-            orage_message(40, "add done foreign file=%s", file_name);
+        if (orage_foreign_file_add(file_name, read_only, name))
+            orage_message(40, "Add done foreign file=%s", file_name);
         else
-            g_warning("add failed foreign file=%s\n", file_name);
+            orage_message(140, "Add failed foreign file=%s\n", file_name);
     }
 }
 
@@ -324,18 +407,18 @@ static void remove_foreign(gboolean running, char *file_name, gboolean initializ
         /* let's use dbus since server is running there already */
 #ifdef HAVE_DBUS
         if (orage_dbus_foreign_remove(file_name))
-            orage_message(40, "remove done foreign file=%s", file_name);
+            orage_message(40, "Remove done foreign file=%s", file_name);
         else
-            g_warning("remove failed foreign file=%s\n", file_name);
+            orage_message(140, "Remove failed foreign file=%s\n", file_name);
 #else
-        g_warning("Can not do remove foreign file without dbus. failed file=%s\n", file_name);
+        orage_message(140, "Can not do remove foreign file without dbus. Remove failed foreign file=%s\n", file_name);
 #endif
     }
     else if (!running && initialized) { /* do it self directly */
         if (orage_foreign_file_remove(file_name))
-            orage_message(40, "remove done foreign file=%s", file_name);
+            orage_message(40, "Remove done foreign file=%s", file_name);
         else
-            g_warning("remove failed foreign file=%s\n", file_name);
+            orage_message(140, "Remove failed foreign file=%s\n", file_name);
     }
 }
 
@@ -345,6 +428,7 @@ static gboolean process_args(int argc, char *argv[], gboolean running
     int argi;
     gboolean end = FALSE;
     gboolean foreign_file_read_only = TRUE;
+    gboolean foreign_file_name_parameter = FALSE;
     gchar *export_uid_list = NULL;
     gchar *file_name = NULL;
 
@@ -399,11 +483,26 @@ static gboolean process_args(int argc, char *argv[], gboolean running
                     !strcmp(argv[argi+2], "RW") ||
                     !strcmp(argv[argi+2], "READWRITE"))) {
                     foreign_file_read_only = FALSE;
+                    if (argi+3 < argc) {
+                        file_name = g_strdup(argv[argi+3]);
+                        foreign_file_name_parameter = TRUE;
+                    }
+                }
+                else if (argi+2 < argc) { /* take argi+2 as name of file */
+                    file_name = g_strdup(argv[argi+2]);
+                    foreign_file_name_parameter = TRUE;
+                }
+                if (!file_name) {
+                    file_name = g_path_get_basename(argv[argi+1]);
                 }
                 add_foreign(running, argv[++argi], initialized
-                        , foreign_file_read_only);
+                        , foreign_file_read_only, file_name);
                 if (!foreign_file_read_only)
                     ++argi;
+                if (foreign_file_name_parameter) {
+                    ++argi;
+                }
+                g_free(file_name);
             }
         }
         else if (!strcmp(argv[argi], "--remove-foreign") ||
@@ -533,18 +632,22 @@ int main(int argc, char *argv[])
         gtk_widget_hide(((CalWin *)g_par.xfcal)->mWindow);
     }
     alarm_read();
-    orage_day_change(FALSE); /* first day change after we start */
+    orage_day_change(NULL); /* first day change after we start */
     mCalendar_month_changed_cb(
             (GtkCalendar *)((CalWin *)g_par.xfcal)->mCalendar, NULL);
 
-    /* start monitoring foreign file updates if we have foreign files */
-    if (g_par.foreign_count)
-        g_timeout_add_seconds(30, (GtkFunction)orage_foreign_files_check, NULL);
-                                                        
+    /* start monitoring external file updates */
+    g_timeout_add_seconds(30, (GtkFunction)orage_external_update_check, NULL);
+
     /* let's check if I got filename as a parameter */
     initialized = TRUE;
     process_args(argc, argv, running, initialized);
 
+#ifdef HAVE_DBUS
+    /* day change after resuming */
+    handle_resuming();
+#endif
+
     gtk_main();
     keep_tidy();
     return(EXIT_SUCCESS);
