@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2013 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2004-2005 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -107,7 +107,10 @@ static void mFile_close_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    gtk_widget_hide(cal->mWindow);
+    if (g_par.close_means_quit)
+        gtk_main_quit();
+    else
+        gtk_widget_hide(cal->mWindow);
 }
 
 static void mFile_quit_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
@@ -193,14 +196,29 @@ static void mHelp_help_activate_cb(GtkMenuItem *menuitem, gpointer user_data)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    helpdoc = g_strconcat("firefox ", PACKAGE_DATA_DIR
+    helpdoc = g_strconcat("exo-open ", PACKAGE_DATA_DIR
            , G_DIR_SEPARATOR_S, "orage"
            , G_DIR_SEPARATOR_S, "doc"
            , G_DIR_SEPARATOR_S, "C"
            , G_DIR_SEPARATOR_S, "orage.html"
            , NULL);
-    if (!orage_exec(helpdoc, FALSE, &error))
-        orage_message(100, "start of %s failed: %s", helpdoc, error->message);
+    if (!orage_exec(helpdoc, FALSE, &error)) {
+        orage_message(10, "%s failed: %s. Trying firefox", helpdoc
+                                    , error->message);
+        g_clear_error(&error);
+        g_free(helpdoc);
+        helpdoc = g_strconcat("firefox ", PACKAGE_DATA_DIR
+               , G_DIR_SEPARATOR_S, "orage"
+               , G_DIR_SEPARATOR_S, "doc"
+               , G_DIR_SEPARATOR_S, "C"
+               , G_DIR_SEPARATOR_S, "orage.html"
+               , NULL);
+        if (!orage_exec(helpdoc, FALSE, &error)) {
+            orage_message(100, "start of %s failed: %s", helpdoc
+                    , error->message);
+            g_clear_error(&error);
+        }
+    }
     g_free(helpdoc);
 }
 
@@ -380,6 +398,8 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
     GtkWidget *ev, *label;
     CalWin *cal = (CalWin *)g_par.xfcal;
     gchar *tip, *tmp, *tmp_title, *tmp_note;
+    gchar *tip_title, *tip_location, *tip_note;
+    gchar *format_bold = "<b> %s </b>";
     struct tm *t;
     char  *l_time, *s_time, *s_timeonly, *e_time, *c_time, *na, *today;
     gint  len;
@@ -389,7 +409,9 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
 #endif
     /***** add data into the vbox *****/
     ev = gtk_event_box_new();
-    tmp_title = orage_process_text_commands(appt->title);
+    tmp_title = appt->title
+            ? orage_process_text_commands(appt->title)
+            : g_strdup(_("No title defined"));
     s_time = g_strdup(orage_icaltime_to_i18_time(appt->starttimecur));
     if (todo) {
         e_time = g_strdup(appt->use_due_time
@@ -442,27 +464,52 @@ static void add_info_row(xfical_appt *appt, GtkBox *parentBox, gboolean todo)
         g_free(e_time);
     }
 
-    /***** set hint *****/
-    tmp_note = orage_process_text_commands(appt->note);
+    /***** set tooltip hint *****/
+    tip_title = g_markup_printf_escaped(format_bold, tmp_title);
+    if (appt->location) {
+        tmp = g_markup_printf_escaped(format_bold, appt->location);
+        tip_location = g_strdup_printf(_(" Location: %s\n"), tmp);
+        g_free(tmp);
+    }
+    else {
+        tip_location = g_strdup("");
+    }
+    if (appt->note) {
+        tmp_note = orage_process_text_commands(appt->note);
+        tmp_note = orage_limit_text(tmp_note, 50, 10);
+        tmp = g_markup_escape_text(tmp_note, strlen(tmp_note));
+        tip_note = g_strdup_printf(_("\n Note:\n%s"), tmp);
+        g_free(tmp);
+    }
+    else {
+        tip_note = g_strdup("");
+    }
+
     if (todo) {
         na = _("Never");
         e_time = g_strdup(appt->use_due_time
                 ? orage_icaltime_to_i18_time(appt->endtimecur) : na);
         c_time = g_strdup(appt->completed
                 ? orage_icaltime_to_i18_time(appt->completedtime) : na);
-        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n Due:\t%s\n Done:\t%s\n Note:\n%s")
-                , tmp_title, appt->location, s_time, e_time, c_time, tmp_note);
+
+        tip = g_strdup_printf(_("Title: %s\n%s Start:\t%s\n Due:\t%s\n Done:\t%s%s")
+                , tip_title, tip_location, s_time, e_time, c_time, tip_note);
 
         g_free(c_time);
     }
     else { /* it is event */
         e_time = g_strdup(orage_icaltime_to_i18_time(appt->endtimecur));
-        tip = g_strdup_printf(_("Title: %s\n Location: %s\n Start:\t%s\n End:\t%s\n Note:\n%s")
-                , tmp_title, appt->location, s_time, e_time, tmp_note);
+
+        tip = g_strdup_printf(_("Title: %s\n%s Start:\t%s\n End:\t%s%s")
+                , tip_title, tip_location, s_time, e_time, tip_note);
     }
-    gtk_tooltips_set_tip(cal->Tooltips, ev, tip, NULL);
+
+    gtk_widget_set_tooltip_markup(ev, tip);
+
+    g_free(tip_title);
+    g_free(tip_location);
+    g_free(tip_note);
     g_free(tmp_title);
-    g_free(tmp_note);
     g_free(s_time);
     g_free(e_time);
     g_free(tip);
@@ -487,10 +534,10 @@ static void insert_rows(GList **list, char *a_day, xfical_type ical_type
     }
 }
 
-static gint list_order(gconstpointer a, gconstpointer b)
+static gint event_order(gconstpointer a, gconstpointer b)
 {
 #undef P_N
-#define P_N "list_order: "
+#define P_N "event_order: "
     xfical_appt *appt1, *appt2;
 
 #ifdef ORAGE_DEBUG
@@ -502,6 +549,26 @@ static gint list_order(gconstpointer a, gconstpointer b)
     return(strcmp(appt1->starttimecur, appt2->starttimecur));
 }
 
+static gint todo_order(gconstpointer a, gconstpointer b)
+{
+#undef P_N
+#define P_N "todo_order: "
+    xfical_appt *appt1, *appt2;
+
+#ifdef ORAGE_DEBUG
+    orage_message(-100, P_N);
+#endif
+    appt1 = (xfical_appt *)a;
+    appt2 = (xfical_appt *)b;
+
+    if (appt1->use_due_time && !appt2->use_due_time)
+        return(-1);
+    if (!appt1->use_due_time && appt2->use_due_time)
+        return(1);
+
+    return(strcmp(appt1->endtimecur, appt2->endtimecur));
+}
+
 static void info_process(gpointer a, gpointer pbox)
 {
 #undef P_N
@@ -649,7 +716,7 @@ static void build_mainbox_todo_info(void)
     if (todo_list) {
         gtk_widget_destroy(cal->mTodo_vbox);
         create_mainbox_todo_info();
-        todo_list = g_list_sort(todo_list, list_order);
+        todo_list = g_list_sort(todo_list, todo_order);
         g_list_foreach(todo_list, (GFunc)info_process
                 , cal->mTodo_rows_vbox);
         g_list_free(todo_list);
@@ -706,7 +773,7 @@ static void build_mainbox_event_info(void)
     if (event_list) {
         gtk_widget_destroy(cal->mEvent_vbox);
         create_mainbox_event_info_box();
-        event_list = g_list_sort(event_list, list_order);
+        event_list = g_list_sort(event_list, event_order);
         g_list_foreach(event_list, (GFunc)info_process
                 , cal->mEvent_rows_vbox);
         g_list_free(event_list);
@@ -743,6 +810,19 @@ void build_mainbox_event_box(void)
     xfical_file_close(TRUE);   
 }
 
+void build_mainbox_todo_box(void)
+{
+#undef P_N
+#define P_N "build_mainbox_todo_box: "
+#ifdef ORAGE_DEBUG
+    orage_message(-100, P_N);
+#endif
+    if (!xfical_file_open(TRUE))
+        return;
+    build_mainbox_todo_info();
+    xfical_file_close(TRUE);   
+}
+
 /**********************************************************************
  * This routine is called from ical-code xfical_alarm_build_list_internal
  * and ical files are already open at that time. So make sure ical files
@@ -778,7 +858,6 @@ void build_mainWin(void)
     gdk_colormap_alloc_color(pic1_cmap, &cal->mBlue, FALSE, TRUE);
 
     cal->mAccel_group = gtk_accel_group_new();
-    cal->Tooltips = gtk_tooltips_new();
 
     gtk_window_set_title(GTK_WINDOW(cal->mWindow), _("Orage"));
     gtk_window_set_position(GTK_WINDOW(cal->mWindow), GTK_WIN_POS_NONE);
@@ -814,7 +893,6 @@ void build_mainWin(void)
     g_signal_connect((gpointer) cal->mCalendar, "day_selected"
             , G_CALLBACK(mCalendar_day_selected_cb)
             , (gpointer) cal);
-
     g_signal_connect((gpointer) cal->mCalendar, "month-changed"
             , G_CALLBACK(mCalendar_month_changed_cb), (gpointer) cal);
 
