@@ -1,6 +1,6 @@
 /*      Orage - Calendar and alarm handler
  *
- * Copyright (c) 2005-2011 Juha Kautto  (juha at xfce.org)
+ * Copyright (c) 2005-2013 Juha Kautto  (juha at xfce.org)
  * Copyright (c) 2003-2006 Mickael Graf (korbinus at xfce.org)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -343,6 +343,9 @@ void alarm_read(void)
     for (i = 0; alarm_groups[i] != NULL; i++) {
         orage_rc_set_group(orc, alarm_groups[i]);
         if ((new_alarm = alarm_read_next_alarm(orc, time_now)) != NULL) {
+            /*
+            g_print(P_N "time_now=%s alarm=%s\n", time_now, new_alarm->alarm_time);
+            */
             create_reminders(new_alarm);
             alarm_free(new_alarm);
         }
@@ -706,9 +709,6 @@ static void create_orage_reminder(alarm_struct *l_alarm)
     GtkWidget *hdtReminder;
     orage_ddmmhh_hbox_struct *ddmmhh_hbox;
     GtkWidget *e_hbox;
-#if !GTK_CHECK_VERSION(2,16,0)
-    GtkWidget *e_label;
-#endif
     gchar *tmp;
 
 #ifdef ORAGE_DEBUG
@@ -799,15 +799,10 @@ static void create_orage_reminder(alarm_struct *l_alarm)
             G_CALLBACK(on_btStopNoiseReminder_clicked), l_alarm);
     }
 
-    btRecreateReminder = gtk_button_new_from_stock("gtk-execute");
-#if GTK_CHECK_VERSION(2,16,0)
+    btRecreateReminder = orage_create_custom_stock_button("gtk-ok"
+            , _("Postpone"));
     gtk_widget_set_tooltip_text(btRecreateReminder
             , _("Remind me again after the specified time"));
-#else
-    /* Note that this goes to the main area. Temporary for the version */
-    e_label = gtk_label_new(_("Press <Execute> to remind me again after the specified time:"));
-    gtk_box_pack_end(GTK_BOX(vbReminder), e_label, FALSE, FALSE, 5);
-#endif
     gtk_dialog_add_action_widget(GTK_DIALOG(wReminder)
             , btRecreateReminder, GTK_RESPONSE_OK);
     g_signal_connect((gpointer) btRecreateReminder, "clicked"
@@ -945,10 +940,18 @@ gboolean orage_day_change(gpointer user_data)
 #endif
     t = orage_localtime();
   /* See if the day just changed. 
-     Note that when we are called first time we always have day change. */
-    if (previous_day != t->tm_mday
+     Note that when we are called first time we always have day change. 
+     If user_data is not NULL, we also force day change. */
+    if (user_data
+    || previous_day != t->tm_mday
     || previous_month != t->tm_mon
     || previous_year != t->tm_year + 1900) {
+        if (user_data) {
+            if (g_par.day_timer) { /* need to stop it if running */
+                g_source_remove(g_par.day_timer);
+                g_par.day_timer = 0;
+            }
+        }
         current_year  = t->tm_year + 1900;
         current_month = t->tm_mon;
         current_day   = t->tm_mday;
@@ -985,7 +988,6 @@ static gboolean orage_alarm_clock(gpointer user_data)
 {
 #undef P_N
 #define P_N "orage_alarm_clock: "
-    struct tm *t;
     GList *alarm_l;
     alarm_struct *cur_alarm;
     gboolean alarm_raised=FALSE;
@@ -995,8 +997,7 @@ static gboolean orage_alarm_clock(gpointer user_data)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    t = orage_localtime();
-    time_now = orage_tm_time_to_icaltime(t);
+    time_now = orage_tm_time_to_icaltime(orage_localtime());
   /* Check if there are any alarms to show */
     for (alarm_l = g_list_first(g_par.alarm_list);
          alarm_l != NULL && more_alarms;
@@ -1004,6 +1005,9 @@ static gboolean orage_alarm_clock(gpointer user_data)
         /* remember that it is sorted list */
         cur_alarm = (alarm_struct *)alarm_l->data;
         if (strcmp(time_now, cur_alarm->alarm_time) > 0) {
+            /*
+            g_print(P_N "time_now=%s alarm=%s\n", time_now, cur_alarm->alarm_time);
+            */
             create_reminders(cur_alarm);
             alarm_raised = TRUE;
         }
@@ -1021,7 +1025,7 @@ static void reset_orage_alarm_clock(void)
 {
 #undef P_N
 #define P_N "reset_orage_alarm_clock: "
-    struct tm *t, t_alarm;
+    struct tm *t, t_alarm, t2;
     GList *alarm_l;
     alarm_struct *cur_alarm;
     gchar *next_alarm;
@@ -1031,10 +1035,13 @@ static void reset_orage_alarm_clock(void)
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
 #endif
-    if (g_par.alarm_timer) /* need to stop it if running */
+    if (g_par.alarm_timer) { /* need to stop it if running */
         g_source_remove(g_par.alarm_timer);
+        g_par.alarm_timer = 0;
+    }
     if (g_par.alarm_list) { /* we have alarms */
-        t = orage_localtime();
+        memcpy(&t2, orage_localtime(), sizeof(t2));
+        t = &t2;
         t->tm_mon++;
         t->tm_year = t->tm_year + 1900;
         alarm_l = g_list_first(g_par.alarm_list);
@@ -1070,6 +1077,7 @@ static gboolean orage_tooltip_update(gpointer user_data)
     gint year, month, day, hour, minute, second;
     gint dd, hh, min;
     GDate *g_now, *g_alarm;
+    gchar *tmp;
 
 #ifdef ORAGE_DEBUG
     orage_message(-100, P_N);
@@ -1081,10 +1089,8 @@ static gboolean orage_tooltip_update(gpointer user_data)
     }
     t = orage_localtime();
     tooltip = g_string_new(_("Next active alarms:"));
-#if GTK_CHECK_VERSION(2,16,0)
     g_string_prepend(tooltip, "<span foreground=\"blue\" weight=\"bold\" underline=\"single\">");
     g_string_append(tooltip, " </span>");
-#endif
   /* Check if there are any alarms to show */
     for (alarm_l = g_list_first(g_par.alarm_list);
          alarm_l != NULL && more_alarms;
@@ -1121,14 +1127,17 @@ static gboolean orage_tooltip_update(gpointer user_data)
 /*
     orage_message(10, P_N "tooltip: alarm=%s hh=%d hh=%d min=%d", cur_alarm->alarm_time, dd, hh, min);
 */
-#if GTK_CHECK_VERSION(2,16,0)
             g_string_append(tooltip, "<span weight=\"bold\">");
             tooltip_highlight_helper = g_string_new(" </span>");
             if (cur_alarm->temporary) { /* let's add a small mark */
                 g_string_append_c(tooltip_highlight_helper, '[');
             }
-            g_string_append_printf(tooltip_highlight_helper, 
-                    "%s", cur_alarm->title);
+            tmp = cur_alarm->title 
+                ? g_markup_escape_text(cur_alarm->title
+                        , strlen(cur_alarm->title))
+                : g_strdup(_("No title defined"));
+            g_string_append_printf(tooltip_highlight_helper, "%s", tmp);
+            g_free(tmp);
             if (cur_alarm->temporary) { /* let's add a small mark */
                 g_string_append_c(tooltip_highlight_helper, ']');
             }
@@ -1136,11 +1145,6 @@ static gboolean orage_tooltip_update(gpointer user_data)
                     _("\n%02d d %02d h %02d min to: %s"),
                     dd, hh, min, tooltip_highlight_helper->str);
             g_string_free(tooltip_highlight_helper, TRUE);
-#else
-            g_string_append_printf(tooltip, 
-                    _("\n%02d d %02d h %02d min to: %s"),
-                    dd, hh, min, cur_alarm->title);
-#endif
             alarm_cnt++;
         }
         else /* sorted so scan can be stopped */
@@ -1148,13 +1152,7 @@ static gboolean orage_tooltip_update(gpointer user_data)
     }
     if (alarm_cnt == 0)
         g_string_append_printf(tooltip, _("\nNo active alarms found"));
-    /* deprecated since version 2.16 */
-    /* after 2.16 use gtk_status_icon_set_tooltip_markup to get nicer text */
-#if GTK_CHECK_VERSION(2,16,0)
     gtk_status_icon_set_tooltip_markup((GtkStatusIcon *)g_par.trayIcon, tooltip->str);
-#else
-    gtk_status_icon_set_tooltip((GtkStatusIcon *)g_par.trayIcon, tooltip->str);
-#endif
     g_string_free(tooltip, TRUE);
     return(TRUE);
 }
